@@ -5,7 +5,7 @@
 #' The function provides a generalised access point for merge specific
 #' [RLum-class] objects. Depending on the input object, the
 #' corresponding merge function will be selected.  Allowed arguments can be
-#' found in the documentations of each merge function. 
+#' found in the documentations of each merge function.
 #' Empty list elements (`NULL`) are automatically removed from the input `list`.
 #'
 #' \tabular{lll}{
@@ -15,7 +15,7 @@
 #' [RLum.Results-class] \tab : \tab `merge_RLum.Results`
 #' }
 #'
-#' @param objects [list] of [RLum-class] (**required**): 
+#' @param objects [list] of [RLum-class] (**required**):
 #' list of S4 object of class `RLum`
 #'
 #' @param ... further arguments that one might want to pass to the specific merge function
@@ -24,10 +24,10 @@
 #'
 #' @note So far not for every `RLum` object a merging function exists.
 #'
-#' @section Function version: 0.1.2
+#' @section Function version: 0.1.3
 #'
-#' @author 
-#' Sebastian Kreutzer, Geography & Earth Sciences, Aberystwyth University (United Kingdom)
+#' @author
+#' Sebastian Kreutzer, Institute of Geography, Heidelberg University (Germany)
 #'
 #' @seealso [RLum.Data.Curve-class], [RLum.Data.Image-class],
 #' [RLum.Data.Spectrum-class], [RLum.Analysis-class], [RLum.Results-class]
@@ -52,7 +52,6 @@
 #' ##merge the results and store them in a new object
 #' temp.merged <- get_RLum(merge_RLum(objects = list(temp1, temp2)))
 #'
-#'
 #' @md
 #' @export
 merge_RLum<- function(
@@ -61,23 +60,22 @@ merge_RLum<- function(
 ){
 
   # Integrity check ----------------------------------------------------------
-    if(!is.list(objects)){
-      stop("[merge_RLum()] argument 'objects' needs to be of type list!")
-
-    }
+    if(!inherits(objects, "list"))
+      stop("[merge_RLum()] argument 'objects' needs to be of type list!",
+           call. = FALSE)
 
     ##we are friendly and remove all empty list elements, this helps a lot if we place things
     ##we DO NOT provide a warning as this lower the computation speed in particular cases.
     objects <- objects[!sapply(objects, is.null)]
 
   ##if list is empty afterwards we do nothing
-   if(length(objects) != 0) {
+   if(length(objects) >= 1) {
       ##check if objects are of class RLum
       temp.class.test <- unique(sapply(1:length(objects), function(x) {
         if (!is(objects[[x]], "RLum")) {
           temp.text <-
-            paste(
-              "[merge_RLum()]: At least element", x, "is not of class 'RLum' or a derivative class!"
+            paste0(
+              "[merge_RLum()]: At least element #", x, " is not of class 'RLum' or a derivative class!"
             )
           stop(temp.text, call. = FALSE)
         }
@@ -85,7 +83,7 @@ merge_RLum<- function(
         is(objects[[x]])[1]
       }))
 
-      ##check if objects are consitent
+      ##check if objects are consistent
       if (length(temp.class.test) > 1) {
         ##This is not valid for RLum.Analysis objects
         if (!"RLum.Analysis" %in% temp.class.test) {
@@ -112,8 +110,7 @@ merge_RLum<- function(
       )
 
     }else{
-
-      warning("[merge_RLum()] Nothing was merged as the object list was found to be empty!")
+      warning("[merge_RLum()] Nothing was merged as the object list was found to be empty or contains only one object!")
       return(NULL)
 
     }
